@@ -18,17 +18,17 @@ package cal;
 
 import java.util.Hashtable;
 
-import javax.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletRequest;
 
 public class Entries {
 
-    private Hashtable<String, Entry> entries;
+    private final Hashtable<String, Entry> entries;
     private static final String[] time = { "8am", "9am", "10am", "11am",
             "12pm", "1pm", "2pm", "3pm", "4pm", "5pm", "6pm", "7pm", "8pm" };
     public static final int rows = 12;
 
     public Entries() {
-        entries = new Hashtable<String, Entry>(rows);
+        entries = new Hashtable<>(rows);
         for (int i = 0; i < rows; i++) {
             entries.put(time[i], new Entry(time[i]));
         }
@@ -43,9 +43,11 @@ public class Entries {
     }
 
     public int getIndex(String tm) {
-        for (int i = 0; i < rows; i++)
-            if (tm.equals(time[i]))
+        for (int i = 0; i < rows; i++) {
+            if (tm.equals(time[i])) {
                 return i;
+            }
+        }
         return -1;
     }
 
